@@ -1,6 +1,7 @@
 from selenium import webdriver
 from selenium.webdriver import ChromeOptions
 from selenium.webdriver import FirefoxOptions
+from selenium.webdriver import EdgeOptions
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from webdriver_manager.firefox import GeckoDriverManager
 from webdriver_manager.microsoft import IEDriverManager
@@ -36,6 +37,7 @@ class IEConfig:
 
 
 class EdgeConfig:
+    headless = False
     command_executor = ""
 
 
@@ -82,7 +84,7 @@ class Browser(object):
 
     @staticmethod
     def chrome():
-        if ChromeConfig.command_executor != "":
+        if ChromeConfig.command_executor != "" and ChromeConfig.command_executor[:4] == "http":
             return webdriver.Remote(command_executor=ChromeConfig.command_executor,
                                     desired_capabilities=DesiredCapabilities.CHROME.copy())
 
@@ -94,9 +96,8 @@ class Browser(object):
             chrome_options = ChromeConfig.options
             if ChromeConfig.headless is True:
                 chrome_options.add_argument('--headless')
-
-        driver = webdriver.Chrome(options=chrome_options,
-                                  executable_path=ChromeDriverManager().install())
+        ep = ChromeConfig.command_executor if ChromeConfig.command_executor != "" else ChromeDriverManager().install()
+        driver = webdriver.Chrome(options=chrome_options, executable_path=ep)
         driver.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
             "source": """
             Object.defineProperty(navigator, 'webdriver', {
@@ -107,7 +108,7 @@ class Browser(object):
 
     @staticmethod
     def firefox():
-        if FirefoxConfig.command_executor != "":
+        if FirefoxConfig.command_executor != "" and FirefoxConfig.command_executor[:4] == "http":
             return webdriver.Remote(command_executor=FirefoxConfig.command_executor,
                                     desired_capabilities=DesiredCapabilities.FIREFOX.copy())
 
@@ -120,34 +121,42 @@ class Browser(object):
             if FirefoxConfig.headless is True:
                 firefox_options.headless = True
 
-        driver = webdriver.Firefox(options=firefox_options,
-                                   executable_path=GeckoDriverManager().install())
+        ep = FirefoxConfig.command_executor if FirefoxConfig.command_executor != "" else GeckoDriverManager().install()
+        driver = webdriver.Firefox(options=firefox_options, executable_path=ep)
         return driver
 
     @staticmethod
     def ie():
-        if IEConfig.command_executor != "":
+        if IEConfig.command_executor != "" and ChromeConfig.command_executor[:4] == "http":
             return webdriver.Remote(command_executor=IEConfig.command_executor,
                                     desired_capabilities=DesiredCapabilities.INTERNETEXPLORER.copy())
         return webdriver.Ie(executable_path=IEDriverManager().install())
 
     @staticmethod
     def edge():
-        if EdgeConfig.command_executor != "":
+        if EdgeConfig.command_executor != "" and EdgeConfig.command_executor[:4] == "http":
             return webdriver.Remote(command_executor=EdgeConfig.command_executor,
                                     desired_capabilities=DesiredCapabilities.EDGE.copy())
-        return webdriver.Edge(executable_path=EdgeChromiumDriverManager().install())
+
+        ep = EdgeConfig.command_executor if EdgeConfig.command_executor != "" else EdgeChromiumDriverManager(log_level=1).install()
+        if EdgeConfig.headless is True:
+            edge_options = EdgeOptions()
+            edge_options.headless = True
+            return webdriver.Edge(executable_path=ep, options=edge_options)
+
+        return webdriver.Edge(executable_path=ep)
 
     @staticmethod
     def opera():
-        if OperaConfig.command_executor != "":
+        if OperaConfig.command_executor != "" and OperaConfig.command_executor[:4] == "http":
             return webdriver.Remote(command_executor=OperaConfig.command_executor,
                                     desired_capabilities=DesiredCapabilities.OPERA.copy())
-        return webdriver.Opera(executable_path=OperaDriverManager().install())
+        ep = OperaConfig.command_executor if OperaConfig.command_executor != "" else OperaDriverManager().install()
+        return webdriver.Opera(executable_path=ep)
 
     @staticmethod
     def safari():
-        if SafariConfig.command_executor != "":
+        if SafariConfig.command_executor != "" and SafariConfig.command_executor[:4] == "http":
             return webdriver.Remote(command_executor=SafariConfig.command_executor,
                                     desired_capabilities=DesiredCapabilities.SAFARI.copy())
         return webdriver.Safari(executable_path=SafariConfig.executable_path)
