@@ -38,15 +38,37 @@ def file_data(file, line=1, sheet="Sheet1", key=None):
     """
     if file is None:
         raise FileExistsError("File name does not exist.")
+
+    stack_t = sys_inspect.stack()
+    ins = sys_inspect.getframeinfo(stack_t[1][0])
+    file_dir = os.path.dirname(os.path.abspath(ins.filename))
+
     if os.path.isfile(file) is True:
         file_path = file
-    else:
-        stack_t = sys_inspect.stack()
-        ins = sys_inspect.getframeinfo(stack_t[1][0])
-        file_dir = os.path.dirname(os.path.dirname(os.path.abspath(ins.filename)))
+    elif "/" in file or "\\" in file:
+        file = file.replace("\\", "/")
+        current_dir = os.path.join(file_dir, file)
+        parent_dir = os.path.join(os.path.dirname(file_dir), file)
+        parent_dir_dir = os.path.join(os.path.dirname(os.path.dirname(file_dir)), file)
+        parent_dir_dir_dir = os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(file_dir))), file)
+        parent_dir_dir_dir_dir = os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(file_dir)))), file)
 
+        if os.path.isfile(current_dir) is True:
+            file_path = current_dir
+        elif os.path.isfile(parent_dir) is True:
+            file_path = parent_dir
+        elif os.path.isfile(parent_dir_dir) is True:
+            file_path = parent_dir_dir
+        elif os.path.isfile(parent_dir_dir_dir) is True:
+            file_path = parent_dir_dir_dir
+        elif os.path.isfile(parent_dir_dir_dir_dir) is True:
+            file_path = parent_dir_dir_dir_dir
+        else:
+            raise FileExistsError(f"No '{file}' data file found.")
+    else:
         file_path = None
-        for root, dirs, files in os.walk(file_dir, topdown=False):
+        find_dir = os.path.dirname(file_dir)
+        for root, dirs, files in os.walk(find_dir, topdown=False):
             for f in files:
                 if f == file:
                     file_path = os.path.join(root, file)
@@ -55,6 +77,9 @@ def file_data(file, line=1, sheet="Sheet1", key=None):
                 continue
             break
 
+        if file_path is None:
+            raise FileExistsError(f"No '{file}' data file found.")
+
     suffix = file.split(".")[-1]
     if suffix == "csv":
         data_list = conversion.csv_to_list(file_path, line=line)
@@ -81,6 +106,8 @@ def data(input, name_func=None, doc_func=None, skip_on_empty=False, **legacy):
         ...     actual = add1(input)
         ...     assert_equal(actual, expected)
         ...
+        >> locals()
+        ... 'test_add1_foo_0': <function ...> ...
         >>
         """
 
@@ -100,23 +127,21 @@ def data(input, name_func=None, doc_func=None, skip_on_empty=False, **legacy):
     name_func = name_func or default_name_func
 
     def parameterized_expand_wrapper(f, instance=None):
-        stack = inspect.stack()
-        frame = stack[1]
-        frame_locals = frame[0].f_locals
+        frame_locals = inspect.currentframe().f_back.f_locals
 
-        paramters = parameterized.input_as_callable(input)()
+        parameters = parameterized.input_as_callable(input)()
 
-        if not paramters:
+        if not parameters:
             if not skip_on_empty:
                 raise ValueError(
                     "Parameters iterable is empty (hint: use "
                     "`parameterized.expand([], skip_on_empty=True)` to skip "
                     "this test when the input is empty)"
                 )
-            return wraps(f)(lambda: skip_on_empty_helper())
+            return wraps(f)(skip_on_empty_helper)
 
-        digits = len(str(len(paramters) - 1))
-        for num, p in enumerate(paramters):
+        digits = len(str(len(parameters) - 1))
+        for num, p in enumerate(parameters):
             name = name_func(f, "{num:0>{digits}}".format(digits=digits, num=num), p)
             # If the original function has patches applied by 'mock.patch',
             # re-construct all patches on the just former decoration layer
