@@ -12,79 +12,85 @@ class FindFilePath:
         ins = inspect.getframeinfo(stack_t[1][0])
         this_file_dir = os.path.dirname(os.path.dirname(os.path.abspath(ins.filename)))
 
-        file_path = None
+        _file_path = None
         for root, dirs, files in os.walk(this_file_dir, topdown=False):
             for file in files:
                 if file == name:
-                    file_path = os.path.join(root, file)
+                    _file_path = os.path.join(root, file)
                     break
             else:
                 continue
             break
-        return file_path
+        return _file_path
 
 
 find_file_path = FindFilePath
 
 
-def file_path() -> str:
-    """
-    Returns the absolute path to the directory where the current file resides
-    For example:
-        "/User/tech/you/test_dir/test_sample.py"
-        return "/User/tech/you/test_dir/test_sample.py"
-    """
-    stack_t = inspect.stack()
-    ins = inspect.getframeinfo(stack_t[1][0])
-    return os.path.abspath(ins.filename)
+class File:
 
+    @property
+    def path(self) -> str:
+        """
+        Returns the absolute path to the directory where the current file resides
+        For example:
+            "/User/tech/you/test_dir/test_sample.py"
+            return "/User/tech/you/test_dir/test_sample.py"
+        """
+        stack_t = inspect.stack()
+        ins = inspect.getframeinfo(stack_t[1][0])
+        return os.path.abspath(ins.filename)
 
-def file_dir() -> str:
-    """
-    Returns the absolute path to the directory where the current file resides
-    For example:
-        "/User/tech/you/test_dir/test_sample.py"
-        return "/User/tech/you/test_dir/"
-    """
-    stack_t = inspect.stack()
-    ins = inspect.getframeinfo(stack_t[1][0])
-    return os.path.dirname(os.path.abspath(ins.filename))
+    @property
+    def dir(self) -> str:
+        """
+        Returns the absolute path to the directory where the current file resides
+        For example:
+            "/User/tech/you/test_dir/test_sample.py"
+            return "/User/tech/you/test_dir/"
+        """
+        stack_t = inspect.stack()
+        ins = inspect.getframeinfo(stack_t[1][0])
+        return os.path.dirname(os.path.abspath(ins.filename))
 
+    @property
+    def dir_dir(self) -> str:
+        """
+        Returns the absolute directory path of the current file directory.
+        For example:
+            "/User/tech/you/test_dir/test_sample.py"
+            return "/User/tech/you/"
+        """
+        stack_t = inspect.stack()
+        ins = inspect.getframeinfo(stack_t[1][0])
+        return os.path.dirname(os.path.dirname(os.path.abspath(ins.filename)))
 
-def file_dir_dir() -> str:
-    """
-    Returns the absolute directory path of the current file directory.
-    For example:
-        "/User/tech/you/test_dir/test_sample.py"
-        return "/User/tech/you/"
-    """
-    stack_t = inspect.stack()
-    ins = inspect.getframeinfo(stack_t[1][0])
-    return os.path.dirname(os.path.dirname(os.path.abspath(ins.filename)))
+    @property
+    def dir_dir_dir(self) -> str:
+        """
+        Returns the absolute directory path of the current file directory
+        For example:
+            /User/tech/you/test_dir/test_sample.py
+            return "/User/you/"
+        """
+        stack_t = inspect.stack()
+        ins = inspect.getframeinfo(stack_t[1][0])
+        return os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(ins.filename))))
 
+    @staticmethod
+    def add_to_path(path=None) -> None:
+        """
+        add path to environment variable path.
+        """
+        if path is None:
+            raise FileNotFoundError("Please setting the File Path")
 
-def file_dir_dir_dir() -> str:
-    """
-    Returns the absolute directory path of the current file directory
-    For example:
-        /User/tech/you/test_dir/test_sample.py
-        return "/User/you/"
-    """
-    stack_t = inspect.stack()
-    ins = inspect.getframeinfo(stack_t[1][0])
-    return os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(ins.filename))))
-
-
-def init_env_path(path=None) -> None:
-    """
-    add path to environment variable path.
-    """
-    if path is None:
-        sys.path.insert(1, file_dir_dir())
-    else:
         sys.path.insert(1, path)
 
 
+file = File()
+
+
 class AssertInfo:
     data = []
 
@@ -111,17 +117,20 @@ def diff_json(response_data, assert_data):
         """ list format """
         if len(response_data) == 0:
             print("response is []")
+        else:
+            if isinstance(response_data[0], dict):
+                response_data = sorted(response_data, key=lambda x: x[list(response_data[0].keys())[0]])
+            else:
+                response_data = sorted(response_data)
+
         if len(response_data) != len(assert_data):
             print("list len: '{}' != '{}'".format(len(response_data), len(assert_data)))
 
-        if isinstance(response_data[0], dict):
-            response_data = sorted(response_data, key=lambda x: x[list(response_data[0].keys())[0]])
-        else:
-            response_data = sorted(response_data)
-        if isinstance(assert_data[0], dict):
-            assert_data = sorted(assert_data, key=lambda x: x[list(assert_data[0].keys())[0]])
-        else:
-            assert_data = sorted(assert_data)
+        if len(assert_data) > 0:
+            if isinstance(assert_data[0], dict):
+                assert_data = sorted(assert_data, key=lambda x: x[list(assert_data[0].keys())[0]])
+            else:
+                assert_data = sorted(assert_data)
 
         for src_list, dst_list in zip(response_data, assert_data):
             """ recursion """
