@@ -1,4 +1,5 @@
 # coding=utf-8
+import os
 import time
 import platform
 from selenium.webdriver import Chrome
@@ -10,8 +11,9 @@ from selenium.webdriver.common.action_chains import ActionChains
 from seldom.logging import log
 from seldom.running.config import Seldom
 from seldom.logging.exceptions import NotFindElementError
+from seldom.utils.webdriver_manager_extend import ChromeDriverManager
 
-__all__ = ["WebDriver"]
+__all__ = ["WebDriver", "WebElement"]
 
 
 LOCATOR_LIST = {
@@ -149,10 +151,10 @@ class WebDriver(object):
             self.Keys(id_="kw").enter()
         """
 
-        def __init__(self, index: int  = 0, **kwargs) -> None:
+        def __init__(self, index: int = 0, **kwargs) -> None:
             self.web_elem = WebElement(**kwargs)
-            self.elem = self.web_elem.get_elements()
-            self.web_elem.show_element(self.elem[index])
+            self.elem = self.web_elem.get_elements(index)
+            self.web_elem.show_element(self.elem)
 
         def input(self, text="") -> None:
             log.info("✅ {info}, input '{text}'.".format(info=self.web_elem.info, text=text))
@@ -216,7 +218,7 @@ class WebDriver(object):
         """
         log.info("📖 {}".format(url))
         if isinstance(Seldom.driver, SeleniumWebDriver) is False:
-            Seldom.driver = Chrome()
+            Seldom.driver = Chrome(executable_path=ChromeDriverManager().install())
         Seldom.driver.get(url)
 
     def open(self, url: str) -> None:
@@ -260,7 +262,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {info}, input '{text}'.".format(info=web_elem.info, text=text))
+        log.info("✅ {info} -> input '{text}'.".format(info=web_elem.info, text=text))
         elem.send_keys(text)
         if enter is True:
             elem.send_keys(Keys.ENTER)
@@ -277,7 +279,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {info}, input '{text}' and enter.".format(info=web_elem.info, text=text))
+        log.info("✅ {info} -> input '{text}' and enter.".format(info=web_elem.info, text=text))
         elem.send_keys(text)
         elem.send_keys(Keys.ENTER)
 
@@ -292,7 +294,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, clear input.".format(web_elem.info))
+        log.info("✅ {} -> clear input.".format(web_elem.info))
         elem.clear()
 
     @staticmethod
@@ -307,7 +309,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, click.".format(web_elem.info))
+        log.info("✅ {} -> click.".format(web_elem.info))
         elem.click()
 
     @staticmethod
@@ -321,7 +323,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, slow click.".format(web_elem.info))
+        log.info("✅ {} -> slow click.".format(web_elem.info))
         ActionChains(Seldom.driver).move_to_element(elem).click(elem).perform()
 
     @staticmethod
@@ -335,7 +337,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, right click.".find(web_elem.info))
+        log.info("✅ {} -> right click.".find(web_elem.info))
         ActionChains(Seldom.driver).context_click(elem).perform()
 
     @staticmethod
@@ -349,7 +351,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, move to element.".format(web_elem.info))
+        log.info("✅ {} -> move to element.".format(web_elem.info))
         ActionChains(Seldom.driver).move_to_element(elem).perform()
 
     @staticmethod
@@ -363,7 +365,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, click and hold.".format(web_elem.info))
+        log.info("✅ {} -> click and hold.".format(web_elem.info))
         ActionChains(Seldom.driver).click_and_hold(elem).perform()
 
     @staticmethod
@@ -381,7 +383,7 @@ class WebDriver(object):
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
         action = ActionChains(Seldom.driver)
-        log.info("✅ {}, drag and drop by offset.".format(web_elem.info))
+        log.info("✅ {} -> drag and drop by offset.".format(web_elem.info))
         action.drag_and_drop_by_offset(elem, x, y).perform()
 
     @staticmethod
@@ -395,7 +397,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, double click.".format(web_elem.info))
+        log.info("✅ {} -> double click.".format(web_elem.info))
         ActionChains(Seldom.driver).double_click(elem).perform()
 
     @staticmethod
@@ -409,7 +411,7 @@ class WebDriver(object):
         web_elem = WebElement(link_text=text)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, click link.".format(web_elem.info))
+        log.info("✅ {} -> click link.".format(web_elem.info))
         elem.click()
 
     @staticmethod
@@ -443,7 +445,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, submit.".format(web_elem.info))
+        log.info("✅ {} -> submit.".format(web_elem.info))
         elem.submit()
 
     @staticmethod
@@ -502,7 +504,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {info}, get attribute：{att}.".format(info=web_elem.info, att=attribute))
+        log.info("✅ {info} -> get attribute：{att}.".format(info=web_elem.info, att=attribute))
         return elem.get_attribute(attribute)
 
     @staticmethod
@@ -516,7 +518,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {info}, get text: {text}.".format(info=web_elem.info, text=elem.text))
+        log.info("✅ {info} -> get text: {text}.".format(info=web_elem.info, text=elem.text))
         return elem.text
 
     @staticmethod
@@ -531,7 +533,7 @@ class WebDriver(object):
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
         result = elem.is_displayed()
-        log.info("✅ {info}, element is display: {r}.".format(info=web_elem.info, r=result))
+        log.info("✅ {info} -> element is display: {r}.".format(info=web_elem.info, r=result))
         return result
 
     @property
@@ -611,7 +613,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         web_elem.show_element(elem)
-        log.info("✅ {}, switch to frame.".format(web_elem.info))
+        log.info("✅ {} -> switch to frame.".format(web_elem.info))
         Seldom.driver.switch_to.frame(elem)
 
     @staticmethod
@@ -646,28 +648,43 @@ class WebDriver(object):
         Saves a screenshots of the current window to a PNG image file.
 
         Usage:
-        self.screenshots('/Screenshots/foo.png')
+            self.screenshots()
+            self.screenshots('/Screenshots/foo.png')
         """
-        log.info("📷️  screenshot.")
         if file_path is None:
-            self.images.append(Seldom.driver.get_screenshot_as_base64())
-        else:
+            img_dir = os.path.join(os.getcwd(), "reports", "images")
+            if os.path.exists(img_dir) is False:
+                os.mkdir(img_dir)
+            file_path = os.path.join(img_dir, str(time.time()).split(".")[0] + ".png")
+        if Seldom.debug is True:
+            log.info(f"📷️  screenshot -> ({file_path}).")
             Seldom.driver.save_screenshot(file_path)
+        else:
+            log.info("📷️  screenshot -> HTML report.")
+            self.images.append(Seldom.driver.get_screenshot_as_base64())
 
-    def screenshot(self, file_path: str = None, index: int = 0, **kwargs) -> None:
+    def element_screenshot(self, file_path: str = None, index: int = 0, **kwargs) -> None:
         """
-        Saves a screenshot of the element to a PNG image file.
+        Saves a element screenshot of the element to a PNG image file.
 
         Usage:
-        self.screenshot(css="#id", file_path='/Screenshots/foo.png')
+            self.element_screenshot(css="#id")
+            self.element_screenshot(css="#id", file_path='/Screenshots/foo.png')
         """
-        log.info("📷️ element screenshot.")
+
         web_elem = WebElement(**kwargs)
         elem = web_elem.get_elements(index)
         if file_path is None:
-            self.images.append(elem.screenshot_as_base64)
-        else:
+            img_dir = os.path.join(os.getcwd(), "reports", "images")
+            if os.path.exists(img_dir) is False:
+                os.mkdir(img_dir)
+            file_path = os.path.join(img_dir, str(time.time()).split(".")[0] + ".png")
+        if Seldom.debug is True:
+            log.info(f"📷️ element screenshot -> ({file_path}).")
             elem.screenshot(file_path)
+        else:
+            log.info("📷️ element screenshot -> HTML Report.")
+            self.images.append(elem.screenshot_as_base64)
 
     @staticmethod
     def select(value: str = None, text: str = None, index: int = None, **kwargs) -> None:
@@ -691,9 +708,9 @@ class WebDriver(object):
             self.select(css="#nr", index=2)
         """
         web_elem = WebElement(**kwargs)
-        elem = web_elem.get_elements(index)
+        elem = web_elem.get_elements(0)
         web_elem.show_element(elem)
-        log.info("✅ {}, select option.".format(web_elem.info))
+        log.info("✅ {} -> select option.".format(web_elem.info))
         if value is not None:
             Select(elem).select_by_value(value)
         elif text is not None:
@@ -821,7 +838,7 @@ class WebDriver(object):
         return elems
 
     @staticmethod
-    def get_element(index: int=0, **kwargs):
+    def get_element(index: int = 0, **kwargs):
         """
         Get a set of elements
 
